import unittest
import threading
import requests
from teleop import Teleop


def get_message():
    return {
            "move": False,
            "position": {
                "x": 0.0,
                "y": 0.0,
                "z": 0.0
            },
            "orientation": {
                "w": 1.0,
                "x": 0.0,
                "y": 0.0,
                "z": 0.0
            },
            "reference_frame": "base"
        } 

BASE_URL = 'https://localhost:4443'


class TestPoseCompounding(unittest.TestCase):
    @classmethod
    def __callback(cls, pose, message):
        cls.__last_pose = pose
        cls.__last_message = message
        print(pose)

    @classmethod
    def setUpClass(cls):
        cls.__last_pose = None
        cls.__last_message = None

        cls.teleop = Teleop()
        cls.teleop.subscribe(cls.__callback)
        cls.thread = threading.Thread(target=cls.teleop.run)
        cls.thread.daemon = True
        cls.thread.start()

    def test_response(self):
        payload = get_message()
        response = requests.post(f'{BASE_URL}/pose', json=payload, verify=False, timeout=5)

        self.assertEqual(response.status_code, 200)
        self.assertEqual(response.json(), {"status": "ok"})

    def test_single_position_update(self):
        payload = get_message()
        payload["move"] = True
        response = requests.post(f'{BASE_URL}/pose', json=payload, verify=False, timeout=5)
        payload["move"] = True
        payload["position"]["y"] = 0.1
        response = requests.post(f'{BASE_URL}/pose', json=payload, verify=False, timeout=5)
        self.assertEqual(response.status_code, 200)

        self.assertIsNotNone(self.__last_pose)
        self.assertIsNotNone(self.__last_message)
        self.assertEqual(self.__last_pose[2, 3], 0.1)

    @classmethod
    def tearDownClass(cls):
        cls.teleop.stop()


if __name__ == "__main__":
    unittest.main()



from setuptools import setup, find_packages

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name='teleop',
    version='0.0.2',
    packages=find_packages(),
    long_description=long_description,
    long_description_content_type='text/markdown',
    description='Turns your phone into a robot arm teleoperation device by leveraging the WebXR API',
    install_requires=[
        'Flask',
        'numpy',
        'transforms3d',
        'werkzeug',
        'pytest',
        'requests',
    ],
    package_data={
        'teleop': ['cert.pem', 'key.pem', 'index.html'],
    },
    license='Apache 2.0',
    author='Spes Robotics',
    author_email='contact@spes.ai',
    project_urls={
        'Documentation': 'https://github.com/SpesRobotics/teleop',
        'Source': 'https://github.com/SpesRobotics/teleop',
        'Tracker': 'https://github.com/SpesRobotics/teleop/issues',
    },
)
